@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::create;
 # ABSTRACT: Implements pantry create subcommand
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -19,7 +19,7 @@ sub command_type {
 }
 
 sub valid_types {
-  return qw/node/
+  return qw/node role/
 }
 
 sub _create_node {
@@ -36,6 +36,20 @@ sub _create_node {
   return;
 }
 
+sub _create_role {
+  my ($self, $opt, $name) = @_;
+
+  my $role = $self->pantry->role( $name );
+  if ( -e $role->path ) {
+    $self->usage_error( "Role '$name' already exists" );
+  }
+  else {
+    $role->save;
+  }
+
+  return;
+}
+
 1;
 
 
@@ -50,7 +64,7 @@ Pantry::App::Command::create - Implements pantry create subcommand
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
