@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::strip;
 # ABSTRACT: Implements pantry strip subcommand
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -11,7 +11,7 @@ use autodie;
 use namespace::clean;
 
 sub abstract {
-  return 'Strip recipes or attributes from a node'
+  return 'Strip recipes or attributes from a node or role'
 }
 
 sub command_type {
@@ -19,7 +19,7 @@ sub command_type {
 }
 
 sub valid_types {
-  return qw/node/
+  return qw/node role/
 }
 
 sub options {
@@ -29,27 +29,70 @@ sub options {
 
 sub _strip_node {
   my ($self, $opt, $name) = @_;
+  $self->_strip_obj($opt, 'node', $name);
+}
 
-  my $node = $self->pantry->node( $name )
-    or $self->usage_error( "Node '$name' does not exist" );
+sub _strip_role {
+  my ($self, $opt, $name) = @_;
+  $self->_strip_obj($opt, 'role', $name);
+}
 
-  if ($opt->{recipe}) {
-    $node->remove_from_run_list(map { "recipe[$_]" } @{$opt->{recipe}});
-  }
+my %strippers = (
+  node => {
+    default => 'delete_attribute',
+    override => undef,
+  },
+  role => {
+    default => 'delete_default_attribute',
+    override => 'delete_override_attribute',
+  },
+);
 
-  if ($opt->{default}) {
-    for my $attr ( @{ $opt->{default} } ) {
-      my ($key, $value) = split /=/, $attr, 2; # split on first '='
-      # if they gave a value, we ignore it
-      $node->delete_attribute($key);
+sub _strip_obj {
+  my ($self, $opt, $type, $name) = @_;
+
+  my $obj = $self->_check_name($type, $name);
+
+  $self->_delete_runlist($obj, $opt);
+
+  for my $k ( sort keys %{$strippers{$type}} ) {
+    if ( my $method = $strippers{$type}{$k} ) {
+      $self->_delete_attributes($obj, $opt, $k, $method);
+    }
+    elsif ( $opt->{$k} ) {
+      $k = ucfirst $k;
+      warn "$k attributes do not apply to $type objects.  Skipping them.\n";
     }
   }
 
-  $node->save;
-
+  $obj->save;
   return;
 }
 
+sub _delete_runlist{
+  my ($self, $obj, $opt) = @_;
+  if ($opt->{role}) {
+    $obj->remove_from_run_list(map { "role[$_]" } @{$opt->{role}});
+  }
+  if ($opt->{recipe}) {
+    $obj->remove_from_run_list(map { "recipe[$_]" } @{$opt->{recipe}});
+  }
+  return;
+}
+
+sub _delete_attributes {
+  my ($self, $obj, $opt, $which, $method) = @_;
+  if ($opt->{$which}) {
+    for my $attr ( @{ $opt->{$which} } ) {
+      my ($key, $value) = split /=/, $attr, 2; # split on first '='
+      # if they gave a value, we ignore it
+      $obj->$method($key);
+    }
+  }
+  return;
+}
+
+
 1;
 
 
@@ -64,7 +107,7 @@ Pantry::App::Command::strip - Implements pantry strip subcommand
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
