@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::sync;
 # ABSTRACT: Implements pantry sync subcommand
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -38,6 +38,8 @@ my $rsync_opts = {
 
 sub _sync_node {
   my ($self, $opt, $name) = @_;
+  my $obj = $self->_check_name('node', $name);
+  $name = $obj->name; # canonical name
 
   say "Synchronizing $name";
 
@@ -70,6 +72,10 @@ sub _sync_node {
   $ssh->rsync_put($rsync_opts, "cookbooks", "/var/chef-solo")
     or die "Could not rsync cookbooks\n";
 
+  # rsync roles to remote /var/chef-solo/roles
+  $ssh->rsync_put($rsync_opts, "roles", "/var/chef-solo")
+    or die "Could not rsync roles\n";
+
   # ssh execute chef-solo
   my $command = "chef-solo";
   $command .= " -l debug" if $ENV{PANTRY_CHEF_DEBUG};
@@ -91,6 +97,7 @@ sub _solo_rb_guts {
   return << 'HERE';
 file_cache_path "/var/chef-solo"
 cookbook_path "/var/chef-solo/cookbooks"
+role_path "/var/chef-solo/roles"
 json_attribs "/etc/chef/node.json"
 require 'chef/handler/json_file'
 report_handlers << Chef::Handler::JsonFile.new(:path => "/var/chef-solo/reports")
@@ -112,7 +119,7 @@ Pantry::App::Command::sync - Implements pantry sync subcommand
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
